import videobox
import videobox.main as main
# This script is here only for to make easier in VSCode to start a debug session
videobox.DEBUG = True
main.run()